==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/botservice/kotlin/inputs/DirectLineSpeechChannelArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.botservice.kotlin.inputs

import com.pulumi.azurenative.botservice.inputs.DirectLineSpeechChannelArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * DirectLine Speech channel definition
 * @property channelName The channel name
 * Expected value is 'DirectLineSpeechChannel'.
 * @property etag Entity Tag of the resource
 * @property location Specifies the location of the resource.
 * @property properties The set of properties specific to DirectLine Speech channel resource
 */
public data class DirectLineSpeechChannelArgs(
    public val channelName: Output<String>,
    public val etag: Output<String>? = null,
    public val location: Output<String>? = null,
    public val properties: Output<DirectLineSpeechChannelPropertiesArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.botservice.inputs.DirectLineSpeechChannelArgs> {
    override fun toJava(): com.pulumi.azurenative.botservice.inputs.DirectLineSpeechChannelArgs =
        com.pulumi.azurenative.botservice.inputs.DirectLineSpeechChannelArgs.builder()
            .channelName(channelName.applyValue({ args0 -> args0 }))
            .etag(etag?.applyValue({ args0 -> args0 }))
            .location(location?.applyValue({ args0 -> args0 }))
            .properties(properties?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [DirectLineSpeechChannelArgs].
 */
@PulumiTagMarker
public class DirectLineSpeechChannelArgsBuilder internal constructor() {
    private var channelName: Output<String>? = null

    private var etag: Output<String>? = null

    private var location: Output<String>? = null

    private var properties: Output<DirectLineSpeechChannelPropertiesArgs>? = null

    /**
     * @param value The channel name
     * Expected value is 'DirectLineSpeechChannel'.
     */
    @JvmName("anpluajaaxxkcwjx")
    public suspend fun channelName(`value`: Output<String>) {
        this.channelName = value
    }

    /**
     * @param value Entity Tag of the resource
     */
    @JvmName("xrrsbnvikcnkovhw")
    public suspend fun etag(`value`: Output<String>) {
        this.etag = value
    }

    /**
     * @param value Specifies the location of the resource.
     */
    @JvmName("kchqthiyqpqpokws")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value The set of properties specific to DirectLine Speech channel resource
     */
    @JvmName("rllwrcympbsxuhvd")
    public suspend fun properties(`value`: Output<DirectLineSpeechChannelPropertiesArgs>) {
        this.properties = value
    }

    /**
     * @param value The channel name
     * Expected value is 'DirectLineSpeechChannel'.
     */
    @JvmName("exywexbteghklgkw")
    public suspend fun channelName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.channelName = mapped
    }

    /**
     * @param value Entity Tag of the resource
     */
    @JvmName("ynstdwbhoofmhwdw")
    public suspend fun etag(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.etag = mapped
    }

    /**
     * @param value Specifies the location of the resource.
     */
    @JvmName("pxvpsohdpbpdpwcu")
    public suspend fun location(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.location = mapped
    }

    /**
     * @param value The set of properties specific to DirectLine Speech channel resource
     */
    @JvmName("hcidjnxgsnbbvfof")
    public suspend fun properties(`value`: DirectLineSpeechChannelPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.properties = mapped
    }

    /**
     * @param argument The set of properties specific to DirectLine Speech channel resource
     */
    @JvmName("vxrchlknkjpidokv")
    public suspend
    fun properties(argument: suspend DirectLineSpeechChannelPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = DirectLineSpeechChannelPropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.properties = mapped
    }

    internal fun build(): DirectLineSpeechChannelArgs = DirectLineSpeechChannelArgs(
        channelName = channelName ?: throw PulumiNullFieldException("channelName"),
        etag = etag,
        location = location,
        properties = properties,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/botservice/kotlin/inputs/DirectLineSpeechChannelArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.botservice.kotlin.inputs

import com.pulumi.azurenative.botservice.inputs.DirectLineSpeechChannelArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * DirectLine Speech channel definition
 * @property channelName The channel name
 * Expected value is 'DirectLineSpeechChannel'.
 * @property etag Entity Tag of the resource
 * @property location Specifies the location of the resource.
 * @property properties The set of properties specific to DirectLine Speech channel resource
 */
public data class DirectLineSpeechChannelArgs(
    public val channelName: Output<String>,
    public val etag: Output<String>? = null,
    public val location: Output<String>? = null,
    public val properties: Output<DirectLineSpeechChannelPropertiesArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.botservice.inputs.DirectLineSpeechChannelArgs> {
    override fun toJava(): com.pulumi.azurenative.botservice.inputs.DirectLineSpeechChannelArgs =
        com.pulumi.azurenative.botservice.inputs.DirectLineSpeechChannelArgs.builder()
            .channelName(channelName.applyValue({ args0 -> args0 }))
            .etag(etag?.applyValue({ args0 -> args0 }))
            .location(location?.applyValue({ args0 -> args0 }))
            .properties(properties?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [DirectLineSpeechChannelArgs].
 */
@PulumiTagMarker
public class DirectLineSpeechChannelArgsBuilder internal constructor() {
    private var channelName: Output<String>? = null

    private var etag: Output<String>? = null

    private var location: Output<String>? = null

    private var properties: Output<DirectLineSpeechChannelPropertiesArgs>? = null

    /**
     * @param value The channel name
     * Expected value is 'DirectLineSpeechChannel'.
     */
    @JvmName("wrxlcnasdnvcdjyb")
    public suspend fun channelName(`value`: Output<String>) {
        this.channelName = value
    }

    /**
     * @param value Entity Tag of the resource
     */
    @JvmName("ihfypqnsdmfbaneo")
    public suspend fun etag(`value`: Output<String>) {
        this.etag = value
    }

    /**
     * @param value Specifies the location of the resource.
     */
    @JvmName("tykrbblkeojmbhbe")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value The set of properties specific to DirectLine Speech channel resource
     */
    @JvmName("pjvhtrmekimavplf")
    public suspend fun properties(`value`: Output<DirectLineSpeechChannelPropertiesArgs>) {
        this.properties = value
    }

    /**
     * @param value The channel name
     * Expected value is 'DirectLineSpeechChannel'.
     */
    @JvmName("gfscpyqrskmkvaqv")
    public suspend fun channelName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.channelName = mapped
    }

    /**
     * @param value Entity Tag of the resource
     */
    @JvmName("rkbscgjrfxmpelax")
    public suspend fun etag(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.etag = mapped
    }

    /**
     * @param value Specifies the location of the resource.
     */
    @JvmName("jwnldhdwmjwxoopr")
    public suspend fun location(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.location = mapped
    }

    /**
     * @param value The set of properties specific to DirectLine Speech channel resource
     */
    @JvmName("kededxadvwmmfsnj")
    public suspend fun properties(`value`: DirectLineSpeechChannelPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.properties = mapped
    }

    /**
     * @param argument The set of properties specific to DirectLine Speech channel resource
     */
    @JvmName("aolxcrfwkxeuvdcp")
    public suspend
    fun properties(argument: suspend DirectLineSpeechChannelPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = DirectLineSpeechChannelPropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.properties = mapped
    }

    internal fun build(): DirectLineSpeechChannelArgs = DirectLineSpeechChannelArgs(
        channelName = channelName ?: throw PulumiNullFieldException("channelName"),
        etag = etag,
        location = location,
        properties = properties,
    )
}
